/*
 * Copyright (C) 2003-2004 Christian Siefkes &lt;christian@siefkes.net&gt;.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties;

import java.io.IOException;

/**
 * Classes implementing this interface announce that they should be closed
 * for releasing all resources and stopping any background activity.
 * The creator of a closeable instance is responsible for calling the
 * {@link #close(int)} when the instance is no longer in use.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.4 $, $Date: 2004/05/18 14:06:41 $, $Author: siefkes $
 */
public interface Closeable {

    /**
     * Closes this instance, releasing all resources and stopping any
     * background threads.
     *
     * @param errorCount the number of errors (exceptions) that occurred during
     * calls to this instance (0 if none)
     * @throws IOException if an I/O error occurs
     * @throws ProcessingException if an error occurs during processing any
     * remaining input
     */
     void close(final int errorCount) throws IOException, ProcessingException;

}
