/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties;

/**
 * An abstract processor that just stores a configuration.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.1 $, $Date: 2004/02/10 18:20:42 $, $Author: siefkes $
 */
public abstract class ConfigurableProcessor implements Processor {

    /**
     * Used to configure this instance.
     */
    private final TiesConfiguration config;

    /**
     * Creates a new instance.
     *
     * @param conf used to configure this instance; if <code>null</code>,
     * the {@linkplain TiesConfiguration#CONF standard configuration} is used
     */
    public ConfigurableProcessor(final TiesConfiguration conf) {
        super();
        config = (conf == null) ? TiesConfiguration.CONF : conf;
    }

    /**
     * Returns the configuration used by this instance.
     * @return the used configuration
     */
    public TiesConfiguration getConfig() {
        return config;
    }

}
