/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties;

import java.util.HashMap;
import java.util.Map;

/**
 * A map used to store context-specific key/value pairs in the
 * {@linkplain de.fu_berlin.ties.Processor processing architecture}.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.2 $, $Date: 2004/09/06 14:16:44 $, $Author: siefkes $
 */
public class ContextMap extends HashMap<String, Object> {

    /**
     * Creates a new instance.
     */
    public ContextMap() {
        super();
    }

    /**
     * Creates a new instance.
     *
     * @param initialCapacity the initial capacity
     * @throws IllegalArgumentException if the initial capacity is negative or
     * the load factor is nonpositive
     */
    public ContextMap(final int initialCapacity)
            throws IllegalArgumentException {
        super(initialCapacity);
    }

    /**
     * Creates a new instance.
     *
     * @param initialCapacity the initial capacity
     * @param loadFactor the load factor
     * @throws IllegalArgumentException if the initial capacity is negative or
     * the load factor is nonpositive
     */
    public ContextMap(final int initialCapacity, final float loadFactor)
            throws IllegalArgumentException {
        super(initialCapacity, loadFactor);
    }

    /**
     * Creates a new instance.
     * @param m the map whose mappings are to be placed in this map
     * @throws NullPointerException if the specified map is null
     */
    public ContextMap(final Map<String, Object> m) throws NullPointerException {
        super(m);
    }

}
