/*
 * Copyright (C) 2003-2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties;

import java.io.IOException;

/**
 * Interface for a processor that operates on an input argument. Non-abstract
 * implementations of this interface are loaded via
 * {@link de.fu_berlin.ties.util.Util#createObject(Class, String[])} and thus
 * must provide a suitable constructor. Otherwise reflection-based instantiation
 * will fail.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.2 $, $Date: 2004/03/24 08:56:48 $, $Author: siefkes $
 */
public interface Processor {

    /**
     * Processes an input argument.
     *
     * @param input the input to process
     * @throws IOException if an I/O error occurs
     * @throws ProcessingException if an error occurs during processing
     */
    void process(final String input) throws IOException, ProcessingException;

}
