/*
 * Copyright (C) 2003-2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.classify;

import java.util.Set;

import de.fu_berlin.ties.ProcessingException;
import de.fu_berlin.ties.classify.feature.FeatureVector;

/**
 * Classes implementing this interface must be able to classify items
 * represented by feature vectors.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.6 $, $Date: 2004/04/14 08:45:30 $, $Author: siefkes $
 */
public interface Classifier {

    /**
     * Base configuration key for classifiers.
     */
    String CONFIG_CLASSIFIER = "classifier";

    /**
     * Classifies an item that is represented by a feature vector by choosing
     * the most probable class among a set of candidate classes.
     *
     * @param features the feature vector to consider
     * @param candidateClasses an set of classes that are allowed for this item
     * @return the result of the classification; you can call
     * {@link PredictionDistribution#best()} to get the most probably class
     * @throws ProcessingException if an error occurs during classification
     */
    PredictionDistribution classify(final FeatureVector features,
            final Set candidateClasses) throws ProcessingException;

}
