/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.classify.feature;

import java.util.ArrayList;
import java.util.Collection;

/**
 * This feature vector implementation stores an ordered sequence of features.
 * Internally it uses an {@link java.util.ArrayList} as storage.
 *
 * <p>Instances of this class are not thread-safe and must be synchronized
 * externally, if required.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.2 $, $Date: 2004/09/06 17:22:10 $, $Author: siefkes $
 */
public class DefaultFeatureVector extends FeatureVector {

    /**
     * Store features in an array list.
     */
    private final ArrayList<Feature> store = new ArrayList<Feature>();

    /**
     * Creates a new instance.
     */
    public DefaultFeatureVector() {
        super();
    }

    /**
     * {@inheritDoc}
     */
    public void addAll(final Collection coll) throws ClassCastException {
        // ensure there is enough room for efficiency
        store.ensureCapacity(store.size() + coll.size());

        // delegate to parent
        super.addAll(coll);
    }

    /**
     * {@inheritDoc}
     */
    protected Collection<Feature> store() {
        return store;
    }

}
