/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.context.sensor;

import org.apache.commons.collections.KeyValue;

/**
 * A sensor is an object that looks up information for a token, for example
 * semantic information from gazetteers or thesauri.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.2 $, $Date: 2004/07/07 08:15:29 $, $Author: siefkes $
 */
public interface Sensor {

    /**
     * Looks up a token and returns the information as an array of key/value
     * pairs (values can be <code>null</code>, but <code>null</code> are not
     * allowed). If no information for the given token can be found, an
     * empty array (length 0) is returned.
     *
     * @param token the token to look up
     * @return an array of key/value pairs describing the token
     */
    KeyValue[] lookup(final String token);

}
