/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.eval;

import de.fu_berlin.ties.io.Storable;

/**
 * Provides a read-only view on {@link de.fu_berlin.ties.eval.Accuracy}
 * statistics and the underlying raw counts.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.1 $, $Date: 2004/05/18 13:46:10 $, $Author: siefkes $
 */
public interface AccuracyView extends Storable {

    /**
     * Calculates and returns the <em>accuracy</em>:
     * <em>A</em> = <em>true</em> / (<em>true</em> + <em>false</em>).
     *
     * @return the accuracy
     */
    double getAccuracy();

    /**
     * Returns the number of false decisions.
     * @return the number of false decisions
     */
    long getFalseCount();

    /**
     * Returns the number of true decisions.
     * @return the number of true decisions
     */
    long getTrueCount();

}
