/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.eval;

/**
 * Classes implementing this interface provide input for calculating evaluation
 * metrics: <em>true positives</em>, <em>false negatives</em> and
 * <em>false positives</em>.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.1 $, $Date: 2004/02/02 18:35:57 $, $Author: siefkes $
 */
public interface EvalInput {

    /**
     * Returns the number of false negatives (false rejections).
     * @return the number of false negatives
     */
    long getFalseNeg();

    /**
     * Returns the number of false positives (false acceptances).
     * @return the number of false positives
     */
    long getFalsePos();

    /**
     * Returns the number of true positives (correct recognitions).
     * @return the number of true positives
     */
    long getTruePos();

}
