/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.filter;

import org.dom4j.Element;

import de.fu_berlin.ties.ProcessingException;

/**
 * An oracle decides whether {@link de.fu_berlin.ties.filter.ElementFilter}s
 * should match elements. They can be used to train
 * {@link de.fu_berlin.ties.filter.TrainableFilter}s.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.1 $, $Date: 2004/08/23 17:10:10 $, $Author: siefkes $
 */
public interface Oracle {

    /**
     * Decides whether an element should be accepted by filters.
     *
     * @param element the element to test
     * @return <code>true</code> if filters should accept the element;
     * <code>false</code> otherwise
     * @throws ProcessingException if an error occurs during filtering
     */
    boolean shouldMatch(final Element element) throws ProcessingException;

}
