/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.io;

/**
 * Classes implementing this interface contain multiple
 * {@link de.fu_berlin.ties.io.Storable} objects and support serialization
 * and deserialization of these objects in a human-readable format.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.1 $, $Date: 2004/02/12 18:31:09 $, $Author: siefkes $
 */
public interface RestorableContainer extends StorableContainer {

    /**
     * Restores items stored in a field container and adds them to this
     * instance. The provided field container must have been filled by calling
     * {@link #storeEntries(FieldContainer)} on a container of the same or
     * an equivalent type.
     *
     * @param fContainer the field container to read
     * @throws IllegalArgumentException if <code>fContainer</code> contains
     * a wrong kind of {@link FieldMap}s
     */
    void restoreEntries(final FieldContainer fContainer)
        throws IllegalArgumentException;

}
