/*
 * Copyright (C) 2004 Christian Siefkes &lt;christian@siefkes.net&gt;.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.io;

/**
 * Classes implementing this interface support serialization in a
 * human-readable format, by storing all relevant fields in a
 * {@link de.fu_berlin.ties.io.FieldMap}.
 *
 * <p>Non-abstract implementations of this interface must support
 * deserialization by providing a public constructor that accepts a
 * {@link de.fu_berlin.ties.io.FieldMap} as single parameter that reads all
 * relevant field values from the map. There is no way to enforce this
 * convention (as interfaces cannot contain constructors), but
 * deserialization via {@link de.fu_berlin.ties.io.FieldMap#createObject(Class)}
 * will fail when it is violated. Deserialization is based on a constructor
 * instead of a "restore" or "init" method to allow the deserialization of
 * immutable objects (whose fields cannot be changed after construction).
 *
 * @author Christian Siefkes
 * @version $Revision: 1.1 $, $Date: 2004/02/02 18:49:56 $, $Author: siefkes $
 */
public interface Storable {

    /**
     * Stores all relevant fields of this object in a field map for
     * serialization. An equivalent object can be created by calling
     * {@link de.fu_berlin.ties.io.FieldMap#createObject(Class)} on the created
     * field map.
     *
     * @return the created field map
     */
    FieldMap storeFields();

}
