/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.util;

/**
 * A static class that provides some mathematical utility methods.
 * No instances of this class can be created, only the static members
 * should be used.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.3 $, $Date: 2004/12/06 17:59:41 $, $Author: siefkes $
 */
public final class MathUtils {

    /**
     * Returns the
     * <a href="http://www.xycoon.com/arithmetic_mean.htm">arithmetic mean</a>
     * of an array of values.
     *
     * @param values the values to use
     * @return the arithmetic mean of the values; or NaN (Not-a-Number) if the
     * array is empty or at least one value is NaN
     */
    public static double mean(final double[] values) {
        if (values.length > 1) {
            // multiple values: calculate mean
            double sum = 0.0;

            for (int i = 0; i < values.length; i++) {
                if (Double.isNaN(values[i])) {
                    // return NaN if at least one value is NaN
                    return Double.NaN;
                } else {
                    sum += values[i];
                }
            }

            return sum / values.length;
        } else if (values.length == 1) {
            // single value: calculate as is
            return values[0];
        } else {
            // no values: return NaN
            return Double.NaN;
        }
    }

    /**
     * Private constructor prevents creation of instances.
     */
    private MathUtils() {
        super();
    }

}
