/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.util;

/**
 * Small wrapper class for an <code>int</code> whose value can be changed.
 * Can be used whenever a mutable object is required, e.g. for adjustable
 * status codes ({@link java.lang.Integer} is immutable, <code>int</code> is a
 * primitive).
 *
 * @author Christian Siefkes
 * @version $Revision: 1.1 $, $Date: 2004/02/19 18:16:25 $, $Author: siefkes $
 */
public class MutableInt {

    /**
     * The wrapped <code>int</code> value.
     */
    private int value;

    /**
     * Creates a new instance, setting the initial value to 0.
     */
    public MutableInt() {
        this(0);
    }

    /**
     * Creates a new instance.
     *
     * @param initialValue the initial value to wrap
     */
    public MutableInt(final int initialValue) {
        super();
        value = initialValue;
    }

    /**
     * Returns the wrapped <code>int</code> value.
     * @return the current value
     */
    public int getValue() {
        return value;
    }

    /**
     * Modifies the wrapped <code>int</code> value.
     * @param i the new value
     */
    public void setValue(final int i) {
        value = i;
    }

    /**
     * Returns a string representation of this object.
     *
     * @return a textual representation
     */
    public String toString() {
        return Integer.toString(value);
    }

}
