/*
 * Copyright (C) 2004 Christian Siefkes &lt;christian@siefkes.net&gt;.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.util;

import java.util.Map;

/**
 * A pruner decidedes which map entries should be pruned (deleted), choosing
 * among several candidate entries. Used by
 * {@link de.fu_berlin.ties.util.AdaptableLRUMap} to realize flexible pruning
 * strategies.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.2 $, $Date: 2004/06/04 17:13:22 $, $Author: siefkes $
 */
public interface Pruner {

    /**
     * Sorts an array of map entries that are candidates for being pruned
     * (deleted).
     *
     * @param candidates an array of entries to be considered as candidates for
     * pruning
     * @return a resorted array of the entries, sorted by prunability so the
     * entries that should be preferably pruned come first
     */
    Map.Entry[] sortForPruning(final Map.Entry[] candidates);

}
