/*
 * Copyright (C) 2003-2004 Christian Siefkes &lt;christian@siefkes.net&gt;.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.xml.dom;

import java.io.IOException;

import org.dom4j.Element;

import de.fu_berlin.ties.ContextMap;
import de.fu_berlin.ties.ProcessingException;

import de.fu_berlin.ties.text.TokenContainer;

/**
 * Interface for a processor that operates on elements in XML documents.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.2 $, $Date: 2004/02/05 14:23:57 $, $Author: siefkes $
 */
public interface ElementProcessor {

    /**
     * Processes an element in an XML document, optionally modifying the
     * element or the document it is part of.
     *
     * @param element the element to process
     * @param tokenContainer a container storing all tokens seen in the
     * document so far; {@link TokenContainer#getLast()} contains the textual
     * content of the element and its child elements
     * @param context a map of objects that are made available for processing
     * @throws IOException if an I/O error occurs
     * @throws ProcessingException if an error occurs during processing
     */
    void processElement(final Element element,
            final TokenContainer tokenContainer, final ContextMap context)
            throws IOException, ProcessingException;

}
