/*
 * Copyright (C) 2003-2004 Christian Siefkes &lt;christian@siefkes.net&gt;.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.xml.dom;

import java.io.IOException;

import org.dom4j.Element;

import de.fu_berlin.ties.ContextMap;
import de.fu_berlin.ties.ProcessingException;
import de.fu_berlin.ties.text.TokenDetails;

/**
 * Interface for a processor that operates on tokens in XML documents.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.3 $, $Date: 2004/11/19 14:05:09 $, $Author: siefkes $
 */
public interface TokenProcessor {

    /**
     * Processes a token in an XML element, optionally modifying the
     * element or the document it is part of.
     *
     * @param element the element containing the token
     * @param left the textual contents of the element to the left of the
     * <code>token</code> (in case of mixed contents, only up to the last
     * preceding child element, if any)
     * @param details details about the token to process
     * @param right the textual contents of the element to the right of the
     * <code>token</code> (in case of mixed contents, only up to the next
     * following child element, if any)
     * @param context a map of objects that are made available for processing
     * @throws IOException if an I/O error occurs
     * @throws ProcessingException if an error occurs during processing
     */
    void processToken(final Element element, final String left,
            final TokenDetails details, final String right,
            final ContextMap context) throws IOException, ProcessingException;

}
