/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.xml.dom;

import java.io.IOException;
import java.io.Writer;

import org.dom4j.Document;

import de.fu_berlin.ties.ContextMap;
import de.fu_berlin.ties.DocumentReader;
import de.fu_berlin.ties.TiesConfiguration;

/**
 * An XML stripper converts a XML document to plain text, removing all markup.
 * <p>This class is thread-safe and can be used to convert several documents
 * in parallel.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.4 $, $Date: 2004/08/23 17:11:21 $, $Author: siefkes $
 */
public class XMLStripper extends DocumentReader {

    /**
     * Creates a new instance, using a default extension and the
     * {@linkplain TiesConfiguration#CONF standard configuration}.
     */
    public XMLStripper() {
        this("txt");
    }

    /**
     * Creates a new instance, using the
     * {@linkplain TiesConfiguration#CONF standard configuration}.
     *
     * @param outExt the extension to use for output files
     */
    public XMLStripper(final String outExt) {
        this(outExt, TiesConfiguration.CONF);
    }

    /**
     * Creates a new instance.
     *
     * @param outExt the extension to use for output files
     * @param config used to configure superclasses
     */
    public XMLStripper(final String outExt, final TiesConfiguration config) {
        super(outExt, config);
    }

    /**
     * Strips all markup from an XML document and stores the resulting plain
     * text. This method just delegates to
     * {@link DOMUtils#collectText(org.dom4j.Branch, StringBuffer)}.
     *
     * @param document the document to read
     * @param writer the writer to write the resulting plain text to; flushed
     * but not closed by this method
     * @param context a map of objects that are made available for processing
     * @throws IOException if an I/O error occurs
     */
    public void process(final Document document, final Writer writer,
            final ContextMap context) throws IOException {
        DOMUtils.collectText(document, writer);
    }

}
