/*
 * Copyright (C) 2004 Christian Siefkes <christian@siefkes.net>.
 * Development of this software is supported by the German Research Society,
 * Berlin-Brandenburg Graduate School in Distributed Information Systems
 * (DFG grant no. GRK 316).
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, visit
 * http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.fu_berlin.ties.xml.io;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.Reader;
import java.io.Writer;

import org.dom4j.Document;
import org.dom4j.DocumentException;

/**
 * Interface for classes that support reading and writing XML documents.
 *
 * @author Christian Siefkes
 * @version $Revision: 1.1 $, $Date: 2004/12/09 18:10:52 $, $Author: siefkes $
 */
public interface DocumentSerializer {

    /**
     * Reads an XML document from a given reader. <strong>Typically a stream
     * should be used instead ({@link #readDocument(InputStream)}) to ensure
     * that encoding issues are handled correctly.</strong>
     *
     * @param reader reader containing the text to parse; not closed by this
     * method
     * @return the newly created document
     * @throws DocumentException if an error occurs during parsing
     * @throws IOException if an I/O error occurrs
     */
    Document readDocument(final Reader reader)
    throws DocumentException, IOException;

    /**
     * Reads an XML document from a given stream.
     *
     * @param in stream containing the text to parse; not closed by this method
     * @return the newly created document
     * @throws DocumentException if an error occurs during parsing
     * @throws IOException if an I/O error occurrs
     */
    Document readDocument(final InputStream in)
    throws DocumentException, IOException;

    /**
     * Writes an XML document to a given writer. <strong>Typically a stream
     * should be used instead ({@link #writeDocument(Document, OutputStream)})
     * to ensure that encoding issues are handled correctly.</strong>
     *
     * @param document the document to write
     * @param writer the writer to write the document text to; flushed
     * but not closed by this method
     * @throws IOException if an I/O error occurrs
     */
    void writeDocument(final Document document, final Writer writer)
    throws IOException;

    /**
     * Writes an XML document to a given stream .
     *
     * @param document the document to write
     * @param out the stream to write the document text to; flushed
     * but not closed by this method
     * @throws IOException if an I/O error occurs during writing
     */
    Document writeDocument(final Document document, final OutputStream out)
    throws IOException;

}
